<?php

/**
 * @file
 * CMK Drush command wrappers.
 */

/**
 * Implements hook_drush_command().
 */
function cmk_cmi_bridge_drush_command() {
  $items = array();

  $items['cmk-config-list'] = array(
    'callback' => 'cmk_drush_config_list',
    'description' => 'List config names by type.',
    'arguments' => array(
      'type'      => 'Type of export, eg "views" or "page_manager/handlers"',
    ),
  );

  $items['cmk-config-export'] = array(
    'callback' => 'cmk_drush_config_export',
    'description' => 'Export configuration to a module.',
    'arguments' => array(
      'label'    => 'A config module label (i.e. a key in cmk_cmi_bridge_config_modules variable). Defaults to sync',
    ),
    'options' => array(
      'destination' => 'An arbitrary module that should receive the exported files. An alternative to label argument.',
    ),
  );

  $items['cmk-config-import'] = array(
    'callback' => 'cmk_drush_config_import',
    'description' => 'Export configuration from a module.',
    'arguments' => array(
      'label'    => 'A config module label (i.e. a key in cmk_cmi_bridge_config_modules variable). Defaults to sync',
    ),
    'options' => array(
      'source' => 'An arbitrary module that holds the configuration code. An alternative to label argument.',
    ),
  );

  return $items;
}

/**
 * Export all exportables into the configured or provided module.
 *
 * Example: drush cmk-config-export
 *
 * @param string|null $label
 *   Name in config_modules array corresponding the module to export to.
 *
 * @return bool
 *   TRUE on success, FALSE otherwise.
 */
function cmk_drush_config_export($label = null) {
  if (!($module = drush_get_option('destination'))) {
    $label = $label ?? 'sync';
    $config_modules = variable_get('cmk_cmi_bridge_config_modules');
    $module = $config_modules[$label];
  }
  $exportables = cmk_exportables();
  foreach ($exportables as $type_or_ns => $info) {
    drush_invoke('cmk-export', [$module, $type_or_ns]);
  }
  return TRUE;
}

/**
 * Import all exportables from the configured or provided module.
 *
 * Example: drush cmk-config-import
 *
 * @param string|null $label
 *   Name in config_modules array corresponding the module to export to.
 *
 * @return bool
 *   TRUE on success, FALSE otherwise.
 */
function cmk_drush_config_import($label = null) {
  if (!($module = drush_get_option('source'))) {
    $label = $label ?? 'sync';
    $config_modules = variable_get('cmk_cmi_bridge_config_modules');
    $module = $config_modules[$label];
  }
  $status = drush_invoke('cmk-revert', [$module]);
  return $status;
}

/**
 * Print the status of all exportables in the system.
 *
 * Example: drush cmk-config-list
 *
 * @param string|null $type
 *   The type or namespace to filter the list by.
 *
 * @return bool
 *   TRUE on success, FALSE otherwise.
 */
function cmk_drush_config_list($type = null) {
  drush_invoke('cmk-list', [NULL, $type]);
  return TRUE;
}
